@@ -152,11 +152,11 @@ class HotKeyMacro:
 
         'file' : ``str`` - the location of the macro
 
-        'repeat_forever' : ``bool`` - repeat the macro forever until the trigger is released
+        'repeat' : ``bool`` - repeat the macro forever until the trigger is released
             ~ note: if set to False, the macro will only once when the trigger is pressed
 
-        'repeat_delay' : ``float`` - time to wait before repeating the macro again
-            ~ note: will only wait if repeat_forever is set to True
+        'delay' : ``float`` - time to wait before repeating the macro again
+            ~ note: will only wait if repeat is set to True
     }
     """
 
